==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QEGLContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(egl)



#endif // QT_CONFIG(egl)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QEGLContext::display()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_00024ConcreteWrapper_display_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        const QNativeInterface::QEGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QEGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QEGLContext::display()const", __qt_this)
        EGLDisplay __qt_return_value = __qt_this->display();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 0);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QEGLContext::invalidateContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_00024ConcreteWrapper_invalidateContext_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        QNativeInterface::QEGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QEGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QEGLContext::invalidateContext()", __qt_this)
        __qt_this->invalidateContext();
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNativeInterface::QEGLContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        const QNativeInterface::QEGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QEGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QEGLContext::nativeContext()const", __qt_this)
        EGLContext __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 0);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QEGLContext::fromNative(EGLContext,EGLDisplay,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_fromNative_1native_1EGLContext_1EGLDisplay_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject context0,
 jobject display1,
 QtJambiNativeID shareContext2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QEGLContext::fromNative(EGLContext,EGLDisplay,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        EGLContext __qt_context0 = reinterpret_cast<EGLContext >(QtJambiAPI::convertQNativePointerToNative(__jni_env, context0, 0));
        EGLDisplay __qt_display1 = reinterpret_cast<EGLDisplay >(QtJambiAPI::convertQNativePointerToNative(__jni_env, display1, 0));
        QOpenGLContext* __qt_shareContext2 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext2);
        QOpenGLContext* __qt_return_value = QNativeInterface::QEGLContext::fromNative(__qt_context0, __qt_display1, __qt_shareContext2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(context0)
        Q_UNUSED(display1)
        Q_UNUSED(shareContext2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QEGLContext(){
    using namespace RegistryAPI;

#if QT_CONFIG(egl)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QEGLContext>("QNativeInterface::QEGLContext", "io/qt/gui/nativeinterface/QEGLContext");
    registerNativeInterface<QNativeInterface::QEGLContext>("io/qt/gui/nativeinterface/QEGLContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QEGLContext* _object = dynamic_cast<QNativeInterface::QEGLContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QEGLContext *object = reinterpret_cast<QNativeInterface::QEGLContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QEGLContext *object = reinterpret_cast<const QNativeInterface::QEGLContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(egl)

    registerNativeInterface("io/qt/gui/nativeinterface/QEGLContext", {});

#endif //QT_CONFIG(egl)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QEGLContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(egl)



#endif // QT_CONFIG(egl)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QEGLContext::display()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_00024ConcreteWrapper_display_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        const QNativeInterface::QEGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QEGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QEGLContext::display()const", __qt_this)
        EGLDisplay __qt_return_value = __qt_this->display();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QEGLContext::invalidateContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_00024ConcreteWrapper_invalidateContext_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        QNativeInterface::QEGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QEGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QEGLContext::invalidateContext()", __qt_this)
        __qt_this->invalidateContext();
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNativeInterface::QEGLContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        const QNativeInterface::QEGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QEGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QEGLContext::nativeContext()const", __qt_this)
        EGLContext __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QEGLContext::fromNative(EGLContext,EGLDisplay,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QEGLContext_00024Impl_fromNative_1native_1EGLContext_1EGLDisplay_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject context0,
 jobject display1,
 QtJambiNativeID shareContext2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QEGLContext::fromNative(EGLContext,EGLDisplay,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(egl)
        EGLContext __qt_context0 = reinterpret_cast<EGLContext >(QtJambiAPI::convertQNativePointerToNative(__jni_env, context0));
        EGLDisplay __qt_display1 = reinterpret_cast<EGLDisplay >(QtJambiAPI::convertQNativePointerToNative(__jni_env, display1));
        QOpenGLContext* __qt_shareContext2 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext2);
        QOpenGLContext* __qt_return_value = QNativeInterface::QEGLContext::fromNative(__qt_context0, __qt_display1, __qt_shareContext2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(context0)
        Q_UNUSED(display1)
        Q_UNUSED(shareContext2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(egl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QEGLContext(){
    using namespace RegistryAPI;

#if QT_CONFIG(egl)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QEGLContext>("QNativeInterface::QEGLContext", "io/qt/gui/nativeinterface/QEGLContext");
    registerNativeInterface<QNativeInterface::QEGLContext>("io/qt/gui/nativeinterface/QEGLContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QEGLContext* _object = dynamic_cast<QNativeInterface::QEGLContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QEGLContext *object = reinterpret_cast<QNativeInterface::QEGLContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QEGLContext *object = reinterpret_cast<const QNativeInterface::QEGLContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(egl)

    registerNativeInterface("io/qt/gui/nativeinterface/QEGLContext", {});

#endif //QT_CONFIG(egl)

}
